@@ -28,12 +28,14 @@
 ##'
 ##' @importFrom utils txtProgressBar setTxtProgressBar capture.output
 ##'
-##' @importFrom doParallel registerDoParallel
-##'
-##' @importFrom foreach foreach
+##' @importFrom foreach foreach %dopar%
 ##'
 ##' @importFrom doRNG %dorng%
 ##'
+##' @importFrom doSNOW registerDoSNOW
+##'
+##' @importFrom parallel makeCluster stopCluster
+##'
 ##' @keywords internal
 
 dataBootstrap<-function(model){
@@ -73,16 +75,15 @@ bootstrapSamples<-function(nboot, model, q_f, q_r, interaction, covar,
   Boot_model<-list(NA)
   Diff<-list(NA)
   warnings <- 0
-  pb <- txtProgressBar(
-    title = "Processing the bootstrap confidence intervals",
-    style = 3, min = 0, max = nboot)
   #---------------------------------------------------------------------
   # Without parallelization
   #---------------------------------------------------------------------
   if (numCore == 1){
+    pb <- txtProgressBar(
+      title = "Processing the bootstrap confidence intervals",
+      style = 3, min = 0, max = nboot)
     for(i in 1:nboot){
-      Dataset_boot[[i]]<-dataBootstrap(model=model)
-      lccModel.fit <- lccModel(dataset=Dataset_boot[[i]], resp="resp",
+      lccModel.fit <- lccModel(dataset=dataBootstrap(model=model), resp="resp",
                                subject="subject", covar = covar,
                                method="method", time="time",
                                qf=q_f, qr=q_r,
@@ -130,22 +131,25 @@ bootstrapSamples<-function(nboot, model, q_f, q_r, interaction, covar,
     # With parallelizarion
     #===================================================================
     # Sampling data
-    registerDoParallel(numCore)
-    Dataset_boot <- foreach(i = 1:nboot) %dorng% {
-      dataBootstrap(model=model)
-    }
+    cl <- makeCluster(numCore, type = "SOCK")
+    registerDoSNOW(cl)
+    pb <- txtProgressBar(max=nboot, style=3)
+    progress <- function(n) setTxtProgressBar(pb, n)
+    opts <- list(progress=progress)
     #-------------------------------------------------------------------
-    lccModel.fit <- foreach(i = 1:nboot) %dorng% {
-      lccModel(dataset=Dataset_boot[[i]], resp="resp",
-               subject="subject", covar = covar,
-               method="method", time="time",
-               qf=q_f, qr=q_r,
+    lccModel.fit <- foreach(i = 1:nboot, .options.snow = opts) %dorng% {
+      lccModel(dataset = dataBootstrap(model=model), resp = "resp",
+               subject = "subject", covar = covar,
+               method = "method", time="time",
+               qf = q_f, qr = q_r,
                interaction = interaction, pdmat = pdmat,
                var.class = var.class,
                weights.form = weights.form,
                lme.control = lme.control,
                method.init = method.init)
     }
+    stopCluster(cl)
+    #-------------------------------------------------------------------
     for(i in 1:nboot){
       x<-NULL
       y<-NULL
@@ -174,12 +178,6 @@ bootstrapSamples<-function(nboot, model, q_f, q_r, interaction, covar,
       betas <- list()
       for(j in 2:lev.facA) betas[[j-1]] <- - fx[pat[[j-1]]]
       Diff[[i]]<-betas
-      #-----------------------------------------------------------------
-      # print
-      #-----------------------------------------------------------------
-      #cat("Sample number: ", i, "\n")
-      setTxtProgressBar(pb, i, label=paste( round(i/nboot*100, 0),
-                                           "% done"))
     }
   }
   cat("\n", "  Convergence error in", warnings, "out of",
